@@ -1,26 +1,37 @@
+# imports
 from datetime import datetime
 import os
 import shutil
 
 
+# Function for converting time from timestamp
 def convert_date(timestamp):
     d = datetime.utcfromtimestamp(timestamp)
     formated_date = d.strftime('%d %b %Y, %H %M')
     return formated_date
 
 
-def read_file(path):
+# Function for reading the single file
+def read_file(path=None):
+    if not path:
+        raise NameError('Required path to the file')
     with open(path, 'r') as f:
         data = f.read()
     return data
 
 
-def write_file(path, data):
+# Function for writing data in the single file
+def write_file(path=None, data=None):
+    if not path or not data:
+        raise NameError('Required path to the file and data')
     with open(path, 'w') as f:
-        f.write(data)
+        f.write(str(data))
 
 
-def list_dir(path):
+# Function that returns list of dirs
+def list_dir(path=None):
+    if not path:
+        raise NameError('Required path to dir')
     dirs = []
     for entry in os.listdir(path):
         if os.path.isdir(os.path.join(path, entry)):
@@ -28,7 +39,10 @@ def list_dir(path):
     return dirs
 
 
+# Function that returns list of files
 def get_files(path):
+    if not path:
+        raise NameError('Required path to dir')
     files = []
     dir_entries = os.scandir(path)
     for entry in dir_entries:
@@ -42,7 +56,10 @@ def get_files(path):
     return files
 
 
-def sync(path_a, path_b):
+# Main function for synchronize two folders
+def sync(path_a=None, path_b=None):
+    if not path_a or not path_b:
+        raise NameError('Required path to both dirs')
     logs = ''
     files_in_a = get_files(path_a)
     files_in_b = get_files(path_b)
@@ -65,12 +82,14 @@ def sync(path_a, path_b):
     write_file('./logs.txt', logs)
 
 
-def files(path):
+# Function that prints list of files and their last modified date
+def files(path=None):
     files = get_files(path)
     for file_ in files:
         print(f"{file_['name']}\t Last Modified: {file_['date_str']}")
 
 
+# Function that prints list of dirs
 def dirs(path):
     dirs = list_dir(path)
     for dir_ in dirs:
